#!/usr/bin/env python
# coding: utf-8


# ESA (C) 2000-2021
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.



import matplotlib.pyplot as plt
import numpy as np
import os


def main():
    """
    Makes a single plot based on the original F90 code in plotHistogramFromReal.

    This was designed solely as a dev only tool. This was redone to remove the PGPlot dependency.

    The original code can be seen commented out in evarimgen.

    Output:
        None.
    """

    if os.getenv('DISPLAY') == None:
        print('No display available -- will not display plot.')
        try:
            os.remove('yVals')
        except FileNotFoundError:
            print('Could not remove yVals.')
        try:
            os.remove('xVals')
        except FileNotFoundError:
            print('Could not reemove xVals.')
        return None

    try:
        y_data = np.loadtxt('yVals')
        x_data = np.loadtxt('xVals')
    except FileNotFoundError:
        print('Could not find the temporary data files. The plot will not be produced.')
        return None

    try:
        os.remove('yVals')
    except FileNotFoundError:
        print('Could not remove yVals.')
    try:
        os.remove('xVals')
    except FileNotFoundError:
        print('Could not reemove xVals.')

    
    plt.style.use('dark_background') 
    plt.fill_between(x_data, y_data, [0] * len(y_data))
    plt.axhline(y = 0, color = 'white')
    plt.axvline(x = 0, color = 'white')
    plt.show()

    return None
    

if __name__ == '__main__':
    main()
